/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { KENDO_CONTEXTMENU } from '../directives';
import { PopupService } from '@progress/kendo-angular-popup';
import { IconsService } from '@progress/kendo-angular-icons';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import * as i0 from "@angular/core";
import * as i1 from "./context-menu.component";
import * as i2 from "./context-menu-template.directive";
import * as i3 from "./context-menu-target.directive";
import * as i4 from "./context-menu-target-container.directive";
import * as i5 from "../menu.component";
import * as i6 from "../menu-item.component";
import * as i7 from "../templates/item-template.directive";
import * as i8 from "../templates/item-link-template.directive";
import * as i9 from "../templates/item-content-template.directive";
import * as i10 from "../data-binding/hierachy-binding.directive";
import * as i11 from "../data-binding/flat-binding.directive";
import * as i12 from "../rendering/link.directive";
import * as i13 from "../rendering/arrow.component";
//IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the ContextMenu component.
 *
 * @example
 *
 * ```ts-no-run
 * // Import the ContextMenu module
 * import { ContextMenuModule } from '@progress/kendo-angular-menu';
 *
 * // The browser platform with a compiler
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 * import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
 *
 * import { NgModule } from '@angular/core';
 *
 * // Import the app component
 * import { AppComponent } from './app.component';
 *
 * // Define the app module
 * _@NgModule({
 *     declarations: [AppComponent], // declare app component
 *     imports:      [BrowserModule, BrowserAnimationsModule, ContextMenuModule], // import ContextMenuModule module
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * // Compile and launch the module
 * platformBrowserDynamic().bootstrapModule(AppModule);
 *
 * ```
 */
export class ContextMenuModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ContextMenuModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: ContextMenuModule, imports: [i1.ContextMenuComponent, i2.ContextMenuTemplateDirective, i3.ContextMenuTargetDirective, i4.ContextMenuTargetContainerDirective, i5.MenuComponent, i6.MenuItemComponent, i7.ItemTemplateDirective, i8.ItemLinkTemplateDirective, i9.ItemContentTemplateDirective, i10.HierarchyBindingDirective, i11.FlatBindingDirective, i12.LinkDirective, i13.ExpandArrowComponent], exports: [i1.ContextMenuComponent, i2.ContextMenuTemplateDirective, i3.ContextMenuTargetDirective, i4.ContextMenuTargetContainerDirective, i5.MenuComponent, i6.MenuItemComponent, i7.ItemTemplateDirective, i8.ItemLinkTemplateDirective, i9.ItemContentTemplateDirective, i10.HierarchyBindingDirective, i11.FlatBindingDirective, i12.LinkDirective, i13.ExpandArrowComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ContextMenuModule, providers: [PopupService, IconsService, ResizeBatchService], imports: [i1.ContextMenuComponent, i5.MenuComponent, i13.ExpandArrowComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ContextMenuModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_CONTEXTMENU],
                    imports: [...KENDO_CONTEXTMENU],
                    providers: [PopupService, IconsService, ResizeBatchService]
                }]
        }] });
