/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { QueryList } from '@angular/core';
import { MenuItemComponent } from './menu-item.component';
import { MenuAnimation } from './menu-animation.interface';
import { OpenOnClickSettings } from './open-on-click-settings';
import { ItemTemplateDirective } from './templates/item-template.directive';
import { ItemLinkTemplateDirective } from './templates/item-link-template.directive';
import { MenuSize } from './size';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class MenuBase {
    /**
     * Specifies the Menu items.
     */
    items: any[];
    /**
     * Specifies if the Menu will be vertical ([see example]({% slug vertical_menu %})).
     */
    vertical: boolean;
    /**
     * Specifies that the root items can be opened only on click
     * ([see example]({% slug openclose_menu %}#toc-opening-on-click)).
     */
    openOnClick: boolean | OpenOnClickSettings;
    /**
     * Specifies the delay in milliseconds before the Menu items are opened or closed on item hover
     * or leave ([see example]({% slug openclose_menu %}#toc-delay-on-hover)). Used to avoid the accidental
     * opening or closing of the items.
     */
    hoverDelay: number;
    /**
     * Sets the Menu animation.
     */
    animate: boolean | MenuAnimation;
    /**
     * Sets the Menu size.
     *
     * The possible values are:
     * * `small`
     * * `medium` (default)
     * * `large`
     * * `none`
     *
     */
    size: MenuSize;
    /**
     * @hidden
     */
    itemTemplate: QueryList<ItemTemplateDirective>;
    /**
     * @hidden
     */
    itemLinkTemplate: QueryList<ItemLinkTemplateDirective>;
    /**
     * @hidden
     */
    children: QueryList<MenuItemComponent>;
    /**
     * @hidden
     */
    get rootItems(): any[];
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuBase, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MenuBase, "kendo-menu-base", never, { "items": { "alias": "items"; "required": false; }; "vertical": { "alias": "vertical"; "required": false; }; "openOnClick": { "alias": "openOnClick"; "required": false; }; "hoverDelay": { "alias": "hoverDelay"; "required": false; }; "animate": { "alias": "animate"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, {}, ["itemTemplate", "itemLinkTemplate", "children"], never, false, never>;
}
