/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The settings for the `openOnClick` option.
 */
export interface OpenOnClickSettings {
    /**
     * Specifies the way in which you can toggle the open-on-click behavior.
     *
     * The supported values are:
     * - `"select"`&mdash;The user opens an item with a click and the Menu items open on hover until one of them is selected.
     * - `"leave"`&mdash;The user opens an item with a click and the Menu items open on hover until either one of them is selected, or the mouse pointer leaves the Menu and the predefined delay passes.
     * - `"click"`&mdash;The user opens an item with a click and the Menu items open on hover but do not close when the mouse pointer leaves the Menu. To close the items, the user has to either select an item, or click a random place on the page.
     *
     * @default 'select'
     */
    toggle: 'select' | 'leave' | 'click';
}
/**
 * @hidden
 */
export declare const normalize: (settings: any) => any;
